@@ -5,9 +5,10 @@ from typing import List
 
 from kamaqi.utils.files import read_project_file,save_project_file
 
-app=Typer()
+app=Typer(help="Add apps to your project")
 
-@app.command(name="app")
+@app.command(name="app",
+             help="Add an app to your project")
 def create_app(app_name:str):
 
     project_data=read_project_file()
@@ -19,7 +20,8 @@ def create_app(app_name:str):
 
     save_project_file(project_data)
 
-@app.command(name="apps")
+@app.command(name="apps",
+            help="Add multiple apps to your project")
 def create_apps(apps:List[str]):
 
     project_data=read_project_file()
