@@ -3,9 +3,10 @@ from typing import List
 from kamaqi.utils.files import read_project_file, save_project_file
 
 
-app=Typer()
+app=Typer(help="Remove your apps")
 
-@app.command(name="app")
+@app.command(name="app",
+             help="Remove an app from your project")
 def remove_app(app_name:str):
 
     project_data=read_project_file()
@@ -17,7 +18,8 @@ def remove_app(app_name:str):
 
     save_project_file(project_data)
 
-@app.command(name="apps")
+@app.command(name="apps",
+             help="Remove multiple apps from your project")
 def remove_apps(apps:List[str]):
 
     project_data=read_project_file()
